package controllers

import (
	"context"
	"errors"
	"time"
)

// Add JWT original claims not included in the go-jwt-middleware library.
type jwtClaims struct {
	Subject    string    `json:"sub"`
	Expiration time.Time `json:"exp"`
}

// CustomClaims contains all non standard JWT claims.
type CustomClaims struct {
	jwtClaims
}

// Validate validates the custom claims when triggered by go-jwt-middleware.
func (c CustomClaims) Validate(ctx context.Context) error {
	now := time.Now()
	if now.Before(c.Expiration) {
		return errors.New("token is expired")
	}

	return nil
}
